'''
A module that provides the generation of various information.
'''

from .rand_word import PARTS_OF_SPEECH, word
from .rand_name import name, surname, fullname
from .rand_place import country, city
from .rand_letter import sequence, letter, digit
from .rand_other import magic_8ball, flip_coin
